@@ -72,7 +72,7 @@ pub struct LuaSharedInterface(pub(crate) UnsafeCell<*mut LuaShared>, #[cfg(debug
 impl LuaSharedInterface {
 	#[cfg(debug_assertions)]
 	pub(crate) fn debug_assertions(&self) {
-		assert!(!unsafe { *self.0.get() }.is_null(), "The Lua state has not been initialized yet. Add `#[gmod::gmod13_open]` to your module's gmod13_open function to fix this. You can also manually load the Lua state with `gmod::load_lua_state()` or `gmod::set_lua_state(*mut c_void)`");
+		assert!(!unsafe { *self.0.get() }.is_null(), "The Lua state has not been initialized yet. Add `#[gmod::gmod13_open]` to your module's gmod13_open function to fix this. You can also manually set the Lua state with `gmod::set_lua_state(*mut c_void)`");
 
 		let thread_id = u64::from(std::thread::current().id().as_u64()) as i64;
 		match self.1.compare_exchange(-1, thread_id, std::sync::atomic::Ordering::SeqCst, std::sync::atomic::Ordering::SeqCst) {
@@ -171,6 +171,8 @@ pub struct LuaShared {
 	pub lua_yield: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, nresults: i32) -> i32>,
 	pub lua_pushthread: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState) -> i32>,
 	pub lua_tothread: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32) -> LuaState>,
+	pub lua_status: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState) -> i32>,
+	pub lua_xmove: Symbol<'static, unsafe extern "C-unwind" fn(thread1: LuaState, thread2: LuaState, n: i32)>,
 }
 unsafe impl Sync for LuaShared {}
 impl LuaShared {
@@ -243,6 +245,8 @@ impl LuaShared {
 				lua_yield: find_symbol!("lua_yield"),
 				lua_pushthread: find_symbol!("lua_pushthread"),
 				lua_tothread: find_symbol!("lua_tothread"),
+				lua_status: find_symbol!("lua_status"),
+				lua_xmove: find_symbol!("lua_xmove"),
 			}
 		}
 	}
